@@ -56,6 +56,7 @@ __all__ = (
     "GoogleAnalyticsConnectorProfileCredentialsTypeDef",
     "GoogleAnalyticsMetadataTypeDef",
     "GoogleAnalyticsSourcePropertiesTypeDef",
+    "IncrementalPullConfigTypeDef",
     "InforNexusConnectorProfileCredentialsTypeDef",
     "InforNexusConnectorProfilePropertiesTypeDef",
     "InforNexusSourcePropertiesTypeDef",
@@ -567,7 +568,13 @@ DestinationConnectorPropertiesTypeDef = TypedDict(
 
 DestinationFieldPropertiesTypeDef = TypedDict(
     "DestinationFieldPropertiesTypeDef",
-    {"isCreatable": bool, "isNullable": bool, "isUpsertable": bool},
+    {
+        "isCreatable": bool,
+        "isNullable": bool,
+        "isUpsertable": bool,
+        "isUpdatable": bool,
+        "supportedWriteOperations": List[Literal["INSERT", "UPSERT", "UPDATE"]],
+    },
     total=False,
 )
 
@@ -799,6 +806,10 @@ GoogleAnalyticsSourcePropertiesTypeDef = TypedDict(
     "GoogleAnalyticsSourcePropertiesTypeDef", {"object": str}
 )
 
+IncrementalPullConfigTypeDef = TypedDict(
+    "IncrementalPullConfigTypeDef", {"datetimeTypeFieldName": str}, total=False
+)
+
 InforNexusConnectorProfileCredentialsTypeDef = TypedDict(
     "InforNexusConnectorProfileCredentialsTypeDef",
     {"accessKeyId": str, "userId": str, "secretAccessKey": str, "datakey": str},
@@ -920,7 +931,12 @@ class S3SourcePropertiesTypeDef(
 
 SalesforceConnectorProfileCredentialsTypeDef = TypedDict(
     "SalesforceConnectorProfileCredentialsTypeDef",
-    {"accessToken": str, "refreshToken": str, "oAuthRequest": "ConnectorOAuthRequestTypeDef"},
+    {
+        "accessToken": str,
+        "refreshToken": str,
+        "oAuthRequest": "ConnectorOAuthRequestTypeDef",
+        "clientCredentialsArn": str,
+    },
     total=False,
 )
 
@@ -935,7 +951,11 @@ _RequiredSalesforceDestinationPropertiesTypeDef = TypedDict(
 )
 _OptionalSalesforceDestinationPropertiesTypeDef = TypedDict(
     "_OptionalSalesforceDestinationPropertiesTypeDef",
-    {"errorHandlingConfig": "ErrorHandlingConfigTypeDef"},
+    {
+        "idFieldNames": List[str],
+        "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
+        "writeOperationType": Literal["INSERT", "UPSERT", "UPDATE"],
+    },
     total=False,
 )
 
@@ -1121,7 +1141,9 @@ _RequiredSourceFlowConfigTypeDef = TypedDict(
     },
 )
 _OptionalSourceFlowConfigTypeDef = TypedDict(
-    "_OptionalSourceFlowConfigTypeDef", {"connectorProfileName": str}, total=False
+    "_OptionalSourceFlowConfigTypeDef",
+    {"connectorProfileName": str, "incrementalPullConfig": "IncrementalPullConfigTypeDef"},
+    total=False,
 )
 
 
@@ -1343,6 +1365,7 @@ StartFlowResponseTypeDef = TypedDict(
     {
         "flowArn": str,
         "flowStatus": Literal["Active", "Deprecated", "Deleted", "Draft", "Errored", "Suspended"],
+        "executionId": str,
     },
     total=False,
 )
